#!/bin/sh
# This script must be able to run on busybox-powered devices, so uses POSIX shell instead of bash.

DISTRIBUTION_PACKAGE_DIR="$(dirname "$0")"
TAR_FILE="${DISTRIBUTION_PACKAGE_DIR}/mediaserver.tar.gz"

PRODUCT_NAME="nxgo"

# TARGET_DIR is set either from NX_VMS_INSTALL_DIR environment variable or read from the file
# in the Server data directory.
TARGET_DIR=""

getDataDir()
{
    flashCardMountPoint="$(df | grep "/dev/localstorage" | awk '{print $6}')"
    if [ "${flashCardMountPoint}" = "" ]; then
        echo "Cannot find the mount point of the SD card." >&2
        exit 1
    fi
    echo -n "${flashCardMountPoint}/${PRODUCT_NAME}.data"
}

getStaticDataDir()
{
    appPath="$1"

    appStorageMountPoint="$( \
        ( df "${appPath}" 2>/dev/null || echo "" ) | tail -1 | awk '{print $6}' )"
    if [ -z "${appStorageMountPoint}" ]; then
        echo "Cannot find the mount point of the internal storage." >&2
        exit 1
    fi
    echo -n "${appStorageMountPoint}/${PRODUCT_NAME}.license"
}

setTargetDir()
{
    dataDir="$(getDataDir)"

    if [ -f "${dataDir}/vadp_package_location.txt" ]; then
        TARGET_DIR="$(cat "$(getDataDir)/vadp_package_location.txt")"
    else
        cat <<EOF
===================================================================================================
ATTENTION: Current Server installation is not found; if it is not the first-time installation, some
misconfiguration must have been occurred.
===================================================================================================
EOF
        TARGET_DIR="${DISTRIBUTION_PACKAGE_DIR}"
    fi

    if [ ! -d "${TARGET_DIR}" ]; then
        echo "FAILED: Cannot find the installed Server." >&2
        exit 1
    fi
}

upgradeVms()
{
    moduleDir="${TARGET_DIR}/mediaserver"

    controlSctipt="${moduleDir}/bin/mediaserver.sh"

    if [ -f "${controlSctipt}" ]; then
        "${controlSctipt}" stop
    fi

    # Back up the config if needed.
    configDir="${moduleDir}/etc"
    if [ -d "${configDir}" ]; then
        tmpConfigDir="$(mktemp -d)"
        cp -r "${configDir}/"* "${tmpConfigDir}"
    else
        tmpConfigDir=""
    fi

    # Remove the old installation.
    rm -rf "${moduleDir}"
    if [ "${DISTRIBUTION_PACKAGE_DIR}" != "${TARGET_DIR}" ]; then
        rm "${TARGET_DIR}"/*.sh "${TARGET_DIR}/vadp.xml"
        cp "${DISTRIBUTION_PACKAGE_DIR}"/*.sh "${TARGET_DIR}"
        cp "${DISTRIBUTION_PACKAGE_DIR}/vadp.xml" "${TARGET_DIR}"
    fi

    # Unpack the distribution.
    tar xfv "${TAR_FILE}" -C "${TARGET_DIR}"

    mediaserverDataDir="$(getDataDir)"
    staticDataDir="$(getStaticDataDir "${TARGET_DIR}")"

    # Create data directories and restore the config from the backup.
    mkdir -p "${staticDataDir}"
    mkdir -p "${mediaserverDataDir}"
    echo "${TARGET_DIR}" > "${mediaserverDataDir}/vadp_package_location.txt"
    mkdir -p "${configDir}"
    if [ -n "${tmpConfigDir}" ]; then
        cp -r "${tmpConfigDir}/"* "${configDir}"
        rm -rf "${tmpConfigDir}"
    fi

    # Update the config.
    "${moduleDir}/bin/upgrade_config.sh" \
        "${moduleDir}/etc/mediaserver.conf" \
        "${moduleDir}/share/configs/mediaserver.conf" \
        "${moduleDir}/etc/mediaserver_conf_added_keys.txt" \
        "${moduleDir}/bin/config_helper.sh"

    # Remove the distribution file if it is in the target directory.
    if [ "${DISTRIBUTION_PACKAGE_DIR}" == "${TARGET_DIR}" ]; then
        rm -f "${TAR_FILE}"
    fi

    if [ -z "${NX_NO_AUTOSTART+x}" ]; then #< Start the Server only if NX_NO_AUTOSTART is not set.
        "${controlSctipt}" start
    fi
}

main()
{
    setTargetDir

    if [ "$1" != "" ]; then
        upgradeVms >>"$1" 2>&1
    else
        upgradeVms 2>&1
    fi
}

main "$@"
