#!/bin/sh

# The script should be able to run under busybox shell.

set -e

BASE_DIR="$(dirname "$0")"

MEDIASERVER_BINARY="${BASE_DIR}/../../bin/mediaserver"
LIB_DIR="${BASE_DIR}/.."
FALLBACK_LIB_DIR="${BASE_DIR}"

createFallbackLibSymlink()
{
    LIB_NAME="$1" && shift

    # Get ld.so path from the mediaserver binary.
    INTERPRETER_PATH="$(file "${MEDIASERVER_BINARY}" \
        | grep -Eo '/[^\s]*ld-linux[^\s]*\.so[.0-9]*')"
    if [ -f "${INTERPRETER_PATH}" ]; then
        # Use it to check for existence of the library with an appropriate architecture.
        # `--list` is to avoid execution of the specified library.
        "${INTERPRETER_PATH}" --list "${LIB_NAME}" >/dev/null 2>&1 && return
    fi

    ln -s "$(realpath "${FALLBACK_LIB_DIR}/${LIB_NAME}")" "${LIB_DIR}/${LIB_NAME}"
}

createFallbackLibSymlinks()
{
    for lib in $(cat "${FALLBACK_LIB_DIR}/libs.txt"); do
        createFallbackLibSymlink "${lib}"
    done
}

removeFallbackLibSymlinks()
{
    for lib in $(cat "${FALLBACK_LIB_DIR}/libs.txt"); do
        if [ -f "${LIB_DIR}/${lib}" ]; then
            rm -f "${LIB_DIR}/${lib}"
        fi
    done
}

if [ "$1" = "create" ]; then
    createFallbackLibSymlinks
elif [ "$1" = "remove" ]; then
    removeFallbackLibSymlinks
else # Recreate symlinks by default.
    removeFallbackLibSymlinks
    createFallbackLibSymlinks
fi
